@@ -2,7 +2,7 @@
 #
 # ChartStock - A class for writing the Excel XLSX Stock charts.
 #
-# Copyright 2013-2019, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2021, John McNamara, jmcnamara@cpan.org
 #
 
 from . import chart
@@ -27,9 +27,6 @@ class ChartStock(chart.Chart):
         """
         super(ChartStock, self).__init__()
 
-        if options is None:
-            options = {}
-
         self.show_crosses = 0
         self.hi_low_lines = {}
         self.date_category = True
